==> pyratbay-1.1.2rc1.tar.gz: pyratbay-1.1.2rc1/README.md <==
# Pyrat Bay: Python Radiative Transfer in a Bayesian framework

<img alt="pyratbay" src="https://github.com/pcubillos/pyratbay/blob/master/docs/figures/pyrat_logo.png" width="190">

> A Forward-modeling and retrieval code to model exoplanet atmospheres and spectra.

[![Build Status](https://travis-ci.com/pcubillos/pyratbay.svg?branch=master)](https://travis-ci.com/pcubillos/pyratbay)
[![Documentation Status](https://readthedocs.org/projects/pyratbay/badge/?version=latest)](https://pyratbay.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/pyratbay.svg)](https://pypi.org/project/pyratbay)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/pyratbay.svg)](https://anaconda.org/conda-forge/pyratbay)
[![GitHub](https://img.shields.io/github/license/pcubillos/pyratbay.svg?color=blue)](https://pyratbay.readthedocs.io/en/latest/license.html)


### Install as:
```
pip install pyratbay
```
or:
```
conda install -c conda-forge pyratbay
```

### Docs at:
<https://pyratbay.readthedocs.io/en/latest/>

### Cite as ([ADS](https://ui.adsabs.harvard.edu/abs/2021arXiv210505598C)):

```bibtex
@ARTICLE{CubillosBlecic2021mnrasPyratBay,
       author = {{Cubillos}, Patricio E. and {Blecic}, Jasmina},
        title = "{The {Pyrat Bay} Framework for Exoplanet Atmospheric Modeling: A Population Study of Hubble/WFC3 Transmission Spectra}",
      journal = {arXiv e-prints},
     keywords = {Astrophysics - Earth and Planetary Astrophysics, Astrophysics - Instrumentation and Methods for Astrophysics},
         year = 2021,
        month = may,
          eid = {arXiv:2105.05598},
        pages = {arXiv:2105.05598},
archivePrefix = {arXiv},
       eprint = {2105.05598},
 primaryClass = {astro-ph.EP},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2021arXiv210505598C},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```

==> pyratbay-1.1.6.tar.gz: pyratbay-1.1.6/README.md <==
# Pyrat Bay: Python Radiative Transfer in a Bayesian framework

<img alt="pyratbay" src="https://github.com/pcubillos/pyratbay/blob/master/docs/figures/pyrat_logo.png" width="190">

> A Forward-modeling and retrieval code to model exoplanet atmospheres and spectra.

[![Build Status](https://travis-ci.com/pcubillos/pyratbay.svg?branch=master)](https://travis-ci.com/pcubillos/pyratbay)
[![Documentation Status](https://readthedocs.org/projects/pyratbay/badge/?version=latest)](https://pyratbay.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/pyratbay.svg)](https://pypi.org/project/pyratbay)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/pyratbay.svg)](https://anaconda.org/conda-forge/pyratbay)
[![GitHub](https://img.shields.io/github/license/pcubillos/pyratbay.svg?color=blue)](https://pyratbay.readthedocs.io/en/latest/license.html)


### Install as:
```
pip install pyratbay
```
or:
```
conda install -c conda-forge pyratbay
```

### Docs at:
<https://pyratbay.readthedocs.io/en/latest/>

### Cite as ([ADS](https://ui.adsabs.harvard.edu/abs/2021arXiv210505598C)):

```bibtex
@ARTICLE{CubillosBlecic2021mnrasPyratBay,
       author = {{Cubillos}, Patricio E. and {Blecic}, Jasmina},
        title = "{The PYRAT BAY framework for exoplanet atmospheric modelling: a population study of Hubble/WFC3 transmission spectra}",
      journal = {\mnras},
     keywords = {radiative transfer, methods: statistical, planets and satellites: atmosphere, Astrophysics - Earth and Planetary Astrophysics, Astrophysics - Instrumentation and Methods for Astrophysics},
         year = 2021,
        month = aug,
       volume = {505},
       number = {2},
        pages = {2675-2702},
          doi = {10.1093/mnras/stab1405},
archivePrefix = {arXiv},
       eprint = {2105.05598},
 primaryClass = {astro-ph.EP},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2021MNRAS.505.2675C},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```
